#include <stdio.h>
#include <string.h>
#include <stdint.h>
#include <getopt.h>
#include <dvdread/ifo_read.h>

int main (int argc, char** argv)
{
	/* A simple program to read the number of titles and chapters on a DVD */
	/* Parse command line options */
	int optionindex, c;
	struct option dvdopts[] = { { "dvd-device", 1, 0, 0 }, { "help", 0, 0, 1 } };
	
	char dvddevice[1024] = "/dev/dvd";
	while ( (c = getopt_long (argc, argv, "", dvdopts, &optionindex)) != -1)
	{
		if (c == 0)
			strcpy (dvddevice, optarg);
		
		if (c == 1)
		{
			fprintf (stderr, "Usage: %s [--dvd-device <device>]\n", argv[0]);
			return -5;
		}
	}
	
	dvd_reader_t *dvd_file = DVDOpen (dvddevice);
	if (dvd_file == NULL)
	{
		fprintf (stderr, "No DVD disk found (%s). Insert a DVD disk.\n", dvddevice);
		fprintf (stderr, "Usage: %s [--dvd-device <device>]\n", argv[0]);
		return -1;
	}
	/* Print the volume information */
	char vol_id[120], volset_id[120];
	if (DVDUDFVolumeInfo (dvd_file, vol_id, 120, volset_id, 120) != -1)
		printf ("VolumeID %s\n", vol_id);
	
	/* Open an info handle to the DVD device */
	ifo_handle_t *info = ifoOpen (dvd_file, 0);
	if (info == NULL)
	{
		fprintf (stderr, "Cannot read the main IFO file!");
		return -2;
	}
	/* Print the number of titles in the DVD */
	printf ("#Titles %d\n", info->tt_srpt->nr_of_srpts);
	
	int i;
	/* Print each title and # of chapters contained therein */
	printf ("Title\t\tChapters\n");
	for (i=0; i < info->tt_srpt->nr_of_srpts; i ++)
		printf ("%d\t\t%d\n", i+1, info->tt_srpt->title[i].nr_of_ptts);

	/* Close the info handles and close the DVD device handle */
	ifoClose (info);
	DVDClose (dvd_file);
	return 0;
}
